/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.executable;

import static org.fortiss.af3.generator.common.utils.SourceModelElementFactory.createStaticContentSourceUnit;

import java.util.List;
import java.util.Map;

import org.fortiss.af3.component.model.Component;
import org.fortiss.af3.component.model.Port;
import org.fortiss.af3.generator.common.model.source.SourcePackage;
import org.fortiss.af3.platform.language.executable.TransmissionUnitExecutableBase;
import org.fortiss.af3.platform.model.ExecutionUnit;
import org.fortiss.af3.platform.model.TransmissionUnit;
import org.fortiss.af3.platform.raspberry.generated.files.RaspberryMakeMKGeneration;
import org.fortiss.af3.platform.raspberry.generated.files.RaspberryMakefileGeneration;
import org.fortiss.af3.platform.raspberry.templates.RaspberryTemplateLoader;

/**
 * 
 * @author chaudhary
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class CANBusExecutable extends TransmissionUnitExecutableBase<TransmissionUnit> {

	/**
	 * @param modelElement
	 */
	public CANBusExecutable(TransmissionUnit modelElement) {
		super(modelElement);
		// TODO Auto-generated constructor stub
	}

	/** {@inheritDoc} */
	@Override
	public void createAllFiles(SourcePackage pack, Map<ExecutionUnit, List<Port>> euPortsPair,
			Map<ExecutionUnit, List<Component>> euComponentList, Component topComponent,
			int deploymentID) {
		createMakeFile(pack, "test_targetName");
		createMakeMK(pack);

	}

	/*
	 * More elegant way of creating files but not working right now. Problem with the special
	 * characters (i.e. $) in MakeFileTemplate.stg
	 */
	private void createMakeFileUsingTemplate(SourcePackage pack) {
		String content = RaspberryTemplateLoader.getMakeFileTemplate("test_executable").toString();
		pack.addUnit(createStaticContentSourceUnit("Makefile", content, false));
	}

	/** Creates a Makefile for an executable with a certain targetname. */
	private void createMakeFile(SourcePackage pack, String targetname) {
		RaspberryMakefileGeneration rspMakefileGen = new RaspberryMakefileGeneration(targetname);
		rspMakefileGen.createMakefile();
		pack.addUnit(createStaticContentSourceUnit("Makefile", rspMakefileGen.getContent(), false));

	}

	/** Creates the make.mk file. */
	private void createMakeMK(SourcePackage pack) {
		// TODO: needs to be implemented similar to createMakeFile methods
		RaspberryMakeMKGeneration rspMakeMK = new RaspberryMakeMKGeneration();
		rspMakeMK.createMakeMK();
		pack.addUnit(createStaticContentSourceUnit("make.mk", rspMakeMK.getContent(), false));

	}
}
